@@ -1,4 +1,4 @@
-package MooX::Role::DBIConnection 0.06;
+package MooX::Role::DBIConnection 0.07;
 use 5.020;
 use experimental 'signatures';
 use Moo::Role;
@@ -74,7 +74,7 @@ sub BUILD( $self, $args ) {
     if( my $_dbh = delete $args->{dbh}) {
         $self->{_dbh_options} = $_dbh;
         if(ref $_dbh eq 'HASH' && $_dbh->{eager}) {
-            $self->reconnect( $_dbh );
+            $self->reconnect_dbh( $_dbh );
         };
     }
 };
@@ -86,14 +86,41 @@ sub _connect_db( $self, $dbh ) {
     return $dbh
 }
 
-sub reconnect( $self, $options = $self->{_dbh_options} ) {
-    $self->{_dbh} = $self->_connect_db( $options )
-}
+=head1 METHODS
+
+The following methods are mixed in through this role:
+
+=head2 C<< ->dbh >>
+
+  my $dbh = $self->dbh;
+
+Connects to the database if needed and returns the database handle
+
+=cut
 
 sub dbh( $self ) {
     return $self->{_dbh} //= $self->_connect_db( $self->{_dbh_options} );
 }
 
+=head2 C<< ->reconnect_dbh >>
+
+  if( my $child = fork ) {
+      ...
+  } else {
+      # in child process
+      # We need a fresh database connection
+      $self->reconnect_dbh;
+  }
+
+Opens a new database connection. If an old connection existed, it is
+not closed.
+
+=cut
+
+sub reconnect_dbh( $self, $options = $self->{_dbh_options} ) {
+    $self->{_dbh} = $self->_connect_db( $options )
+}
+
 1;
 
 =head1 REPOSITORY
